pub struct Definition {
pub name: Name,
pub typ: Type,
pub check: bool,
pub args: Vec<Name>,
pub body: Stmt,
pub source: Source,
}Fields
name: Nametyp: Typecheck: boolargs: Vec<Name>body: Stmtsource: SourceImplementations
Sourceimpl Definition
impl Definition
Sourcepub fn gen_map_get(&mut self)
pub fn gen_map_get(&mut self)
Generates a map from Stmt to Substitutions for each definition in the program.
Iterates over all definitions in the program and applies gen_map_get to their bodies.
It replaces Expr::MapGet expressions with variable accesses, introducing
new variables as necessary to hold intermediate results from map accesses.
Sourceimpl Definition
impl Definition
Sourceimpl Definition
impl Definition
pub fn to_fun(self) -> Result<Definition, Diagnostics>